@@ -4,18 +4,16 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_RUN_APPLICATION_PLUGIN_H
-#define PLUGINS_RUN_APPLICATION_PLUGIN_H
+#pragma once
 
 #include <Plugin.h>
 
 class RunApplicationPlugin : public Plugin
 {
     Q_OBJECT
-    // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.virtualdesktopswitch")
 
 public:
-    explicit RunApplicationPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit RunApplicationPlugin(QObject *parent);
     ~RunApplicationPlugin() override;
 
     bool init(QHash<QString, QObject *> &modules) override;
@@ -32,5 +30,3 @@ private:
     QStringList m_previousActivities;
     QObject *m_activitiesService;
 };
-
-#endif // PLUGINS_RUN_APPLICATION_PLUGIN_H
